Module: ThemeCheck

Defined in:
lib/theme_check/in_memory_storage.rb,
lib/theme_check/cli.rb,
lib/theme_check/node.rb,
lib/theme_check/tags.rb,
lib/theme_check/check.rb,
lib/theme_check/theme.rb,
lib/theme_check/checks.rb,
lib/theme_check/config.rb,
lib/theme_check/offense.rb,
lib/theme_check/printer.rb,
lib/theme_check/storage.rb,
lib/theme_check/version.rb,
lib/theme_check/visitor.rb,
lib/theme_check/analyzer.rb,
lib/theme_check/packager.rb,
lib/theme_check/template.rb,
lib/theme_check/corrector.rb,
lib/theme_check/json_file.rb,
lib/theme_check/json_check.rb,
lib/theme_check/locale_diff.rb,
lib/theme_check/json_helpers.rb,
lib/theme_check/liquid_check.rb,
lib/theme_check/checks_tracking.rb,
lib/theme_check/disabled_checks.rb,
lib/theme_check/language_server.rb,
lib/theme_check/parsing_helpers.rb,
lib/theme_check/checks/liquid_tag.rb,
lib/theme_check/checks/valid_json.rb,
lib/theme_check/checks/syntax_error.rb,
lib/theme_check/checks/valid_schema.rb,
lib/theme_check/file_system_storage.rb,
lib/theme_check/checks/unused_assign.rb,
lib/theme_check/checks/default_locale.rb,
lib/theme_check/checks/nested_snippet.rb,
lib/theme_check/checks/unknown_filter.rb,
lib/theme_check/checks/unused_snippet.rb,
lib/theme_check/shopify_liquid/filter.rb,
lib/theme_check/shopify_liquid/object.rb,
lib/theme_check/checks/template_length.rb,
lib/theme_check/language_server/server.rb,
lib/theme_check/checks/missing_template.rb,
lib/theme_check/checks/undefined_object.rb,
lib/theme_check/language_server/handler.rb,
lib/theme_check/checks/deprecated_filter.rb,
lib/theme_check/checks/space_inside_braces.rb,
lib/theme_check/checks/required_directories.rb,
lib/theme_check/checks/matching_translations.rb,
lib/theme_check/checks/missing_enable_comment.rb,
lib/theme_check/checks/translation_key_exists.rb,
lib/theme_check/checks/valid_html_translation.rb,
lib/theme_check/checks/convert_include_to_render.rb,
lib/theme_check/shopify_liquid/deprecated_filter.rb,
lib/theme_check/checks/parser_blocking_javascript.rb,
lib/theme_check/checks/matching_schema_translations.rb,
lib/theme_check/checks/required_layout_theme_object.rb,
lib/theme_check/checks/missing_required_template_files.rb

Overview

An in-memory storage is not written to disk. The reasons why you'd want to do that are your own. The idea is to not write to disk something that doesn't need to be there. If you have your template as a big hash already, leave it like that and save yourself some IO.

Defined Under Namespace

Modules: ChecksTracking, JsonHelpers, LanguageServer, ParsingHelpers, ShopifyLiquid, Tags Classes: Analyzer, Check, Checks, Cli, Config, ConvertIncludeToRender, Corrector, DefaultLocale, DeprecatedFilter, DisabledChecks, FileSystemStorage, InMemoryStorage, JsonCheck, JsonFile, LiquidCheck, LiquidTag, LocaleDiff, MatchingSchemaTranslations, MatchingTranslations, MissingEnableComment, MissingRequiredTemplateFiles, MissingTemplate, NestedSnippet, Node, Offense, Packager, ParserBlockingJavaScript, Printer, RequiredDirectories, RequiredLayoutThemeObject, SpaceInsideBraces, Storage, SyntaxError, Template, TemplateLength, Theme, TranslationKeyExists, UndefinedObject, UnknownFilter, UnusedAssign, UnusedSnippet, ValidHTMLTranslation, ValidJson, ValidSchema, Visitor

Constant Summary collapse

VERSION =
"0.3.2"